- formula
Formula of a survival object using
Surv of the form, Surv(time, event) ~ group.
The exposure variable (here, group) must be categorical with at
least 2 categories.
- data
Data set.
- time
Time point to estimate survival difference at.
- estimand
Optional. Estimate difference in survival ("survival")
or cumulative incidence ("cuminc")? This parameter affects the
sign of the differences. Only "cuminc" is available if competing
events are present, i.e., event_type is not NULL.
Defaults to "survival".
- type
Optional. Estimate differences ("diff") or ratio
("ratio") of survival or cumulative incidence? Defaults to
"diff".
- approach
Optional. For estimating confidence limits of differences,
use the MOVER approach based on upper and lower confidence limits of each
group ("mover"), or square-and-add standard errors
("squareadd")? Defaults to "mover". (For confidence limits of
ratios, this argument is ignored and MOVER is used.)
- conf.level
Optional. Confidence level. Defaults to 0.95.
- event_type
Optional. Event type (level) for event variable with
competing events. Defaults to NULL.
- id_variable
Optional. Identifiers for individual oberversations,
required if data are clustered, or if competing events and time/time2
notation are used concomitantly.
- weighted
Optional. Weigh survival curves, e.g. for inverse-probability
weighting, before estimating differences or ratios? If TRUE, the
data must contain a variable called .weights. Defaults to
FALSE.